@@ -3,7 +3,7 @@
 use Shell::Cmd;
 $obj = new Shell::Cmd;
 $obj->options("echo" => "echo");
-$obj->options("run"  => "dry-run");
+$obj->options("mode" => "dry-run");
 $obj->cmd("if [ -d /tmp/1 ]; then",   { "flow" => '+' },
           "echo 'case 1'",
           "elif [ -d /tmp/2 ]; then", { "flow" => '=' },
